var searchData=
[
  ['saslanonymous',['SASLAnonymous',['../classQXmppConfiguration.html#afae07ce22ff50481eaa0ebff91c21d11a124eafd393640edc3a4860dd711c8e74',1,'QXmppConfiguration']]],
  ['saslauthmechanism',['SASLAuthMechanism',['../classQXmppConfiguration.html#afae07ce22ff50481eaa0ebff91c21d11',1,'QXmppConfiguration::SASLAuthMechanism()'],['../classQXmppConfiguration.html#acf8e2a0bf51da53af72f1f689232082c',1,'QXmppConfiguration::sASLAuthMechanism() const ']]],
  ['sasldigestmd5',['SASLDigestMD5',['../classQXmppConfiguration.html#afae07ce22ff50481eaa0ebff91c21d11a84c03aaffee784130c781c74eca3c417',1,'QXmppConfiguration']]],
  ['saslplain',['SASLPlain',['../classQXmppConfiguration.html#afae07ce22ff50481eaa0ebff91c21d11a3a7552e191236404ed92c4208e119fc9',1,'QXmppConfiguration']]],
  ['saslxfacebookplatform',['SASLXFacebookPlatform',['../classQXmppConfiguration.html#afae07ce22ff50481eaa0ebff91c21d11a1b8a784020f8989ee89bba62a585ddff',1,'QXmppConfiguration']]],
  ['senddata',['sendData',['../classQXmppStream.html#a7920b8a42c3755dda87e02dbe5e9e626',1,'QXmppStream']]],
  ['senddatagram',['sendDatagram',['../classQXmppRtpAudioChannel.html#ac02d15c55ff0d6e5b6119d5aa104d035',1,'QXmppRtpAudioChannel::sendDatagram()'],['../classQXmppRtpVideoChannel.html#a8df16b8ad5a32f74e40aa6261f09b5e0',1,'QXmppRtpVideoChannel::sendDatagram()'],['../classQXmppIceComponent.html#a13a9f295fdcc5d2b912382054ad627cf',1,'QXmppIceComponent::sendDatagram()']]],
  ['sendelement',['sendElement',['../classQXmppServer.html#a8bfcf9c3734844281ee5581cae350feb',1,'QXmppServer']]],
  ['sendfile',['sendFile',['../classQXmppTransferManager.html#a35b5ec17e13b8f49ac2d29cec3d8b844',1,'QXmppTransferManager::sendFile(const QString &amp;jid, const QString &amp;filePath, const QString &amp;sid=QString())'],['../classQXmppTransferManager.html#a9e08182cdd6f2df3c2d3c19bb9660d24',1,'QXmppTransferManager::sendFile(const QString &amp;jid, QIODevice *device, const QXmppTransferFileInfo &amp;fileInfo, const QString &amp;sid=QString())']]],
  ['sendinvitation',['sendInvitation',['../classQXmppMucRoom.html#a94fbb2e103f48b5cc17661d25f47122e',1,'QXmppMucRoom']]],
  ['sendmessage',['sendMessage',['../classQXmppClient.html#a44d230e24954da4a05e661318494fce4',1,'QXmppClient::sendMessage()'],['../classQXmppMucRoom.html#a7a3ead69818cc6b2c8536384528dbada',1,'QXmppMucRoom::sendMessage()']]],
  ['sendpacket',['sendPacket',['../classQXmppStream.html#a47473db930db0242bb2f6289172b6ea8',1,'QXmppStream::sendPacket()'],['../classQXmppClient.html#a28fb16fe7c83b134e46fea795bfffc35',1,'QXmppClient::sendPacket()'],['../classQXmppServer.html#a7617374585f26e9a4b5c878cc81415d8',1,'QXmppServer::sendPacket()']]],
  ['sentmessage',['SentMessage',['../classQXmppLogger.html#a932dbbd4f70a1e9c0ff8f452e61fc9b8ad1c7d954320b318802468a0655e81b42',1,'QXmppLogger']]],
  ['server',['server',['../classQXmppServerExtension.html#a56847ef0def13090d91cd6f6bded0aed',1,'QXmppServerExtension']]],
  ['serverreflexivetype',['ServerReflexiveType',['../classQXmppJingleCandidate.html#a6314b3ed7de59b68131db6ffab55fe7dadd47f88f0d90666a9b5768c70e407c7f',1,'QXmppJingleCandidate']]],
  ['set',['Set',['../classQXmppIq.html#a6bc7a0505a3be7309051ae2432a3d826a3dc74d347c7b00a2a1cd3b02b4cfd7b0',1,'QXmppIq']]],
  ['setaction',['setAction',['../classQXmppJingleIq.html#a7d3868e6bdc1b042f470a9ad795a811c',1,'QXmppJingleIq']]],
  ['setactor',['setActor',['../classQXmppMucItem.html#a69f1abfed056c472a0e8539935328573',1,'QXmppMucItem']]],
  ['setaffiliation',['setAffiliation',['../classQXmppMucItem.html#ab1b1b9093c3bca933bd073a5ad9a4636',1,'QXmppMucItem']]],
  ['setarguments',['setArguments',['../classQXmppRpcInvokeIq.html#aea362ae92bbd8a29645751ffb5452d20',1,'QXmppRpcInvokeIq']]],
  ['setattentionrequested',['setAttentionRequested',['../classQXmppMessage.html#ad31b0fbbb7dd26ba8c6528a5d93a8a85',1,'QXmppMessage']]],
  ['setautoacceptsubscriptions',['setAutoAcceptSubscriptions',['../classQXmppConfiguration.html#ab3702f9b38d6e97338f27e2d94089ce4',1,'QXmppConfiguration']]],
  ['setautojoin',['setAutoJoin',['../classQXmppBookmarkConference.html#a9d25893b39d5154b555b90d5ad7e2be2',1,'QXmppBookmarkConference']]],
  ['setautoreconnectionenabled',['setAutoReconnectionEnabled',['../classQXmppConfiguration.html#af1b4829231216e457803e46e784c25ba',1,'QXmppConfiguration']]],
  ['setbarejid',['setBareJid',['../classQXmppRosterIq_1_1Item.html#ac58d9f728ffc0a357b9dff093890de11',1,'QXmppRosterIq::Item']]],
  ['setbirthday',['setBirthday',['../classQXmppVCardIq.html#ac7e4d0035d340b433af3bf4a84b81d04',1,'QXmppVCardIq']]],
  ['setbody',['setBody',['../classQXmppArchiveMessage.html#a1e69a102502f866a3fb09d1ba2a932ef',1,'QXmppArchiveMessage::setBody()'],['../classQXmppMessage.html#adfc1b70b910079c76c93ba472fc4e9e7',1,'QXmppMessage::setBody()']]],
  ['setbookmarks',['setBookmarks',['../classQXmppBookmarkManager.html#ac08a572f1426c49e565bf5cd96afee12',1,'QXmppBookmarkManager']]],
  ['setcacertificates',['setCaCertificates',['../classQXmppConfiguration.html#abe15b8d3dc480dfe30242fa0648feb6a',1,'QXmppConfiguration']]],
  ['setcapabilityhash',['setCapabilityHash',['../classQXmppPresence.html#a4a8355d4ce1f84a97fdb098d7856829a',1,'QXmppPresence']]],
  ['setcapabilitynode',['setCapabilityNode',['../classQXmppPresence.html#a087a58383725086449c9b7d8a428d4be',1,'QXmppPresence']]],
  ['setcapabilityver',['setCapabilityVer',['../classQXmppPresence.html#ab6434834049a20ef0711263adfd3686d',1,'QXmppPresence']]],
  ['setchannels',['setChannels',['../classQXmppJinglePayloadType.html#aae85a93d980283519b526b6078c7d7ba',1,'QXmppJinglePayloadType']]],
  ['setchat',['setChat',['../classQXmppArchiveChatIq.html#a813de01a9d74c7d05bd2cfdc094689d2',1,'QXmppArchiveChatIq']]],
  ['setchats',['setChats',['../classQXmppArchiveListIq.html#ae952398e8b3f23c0f25f46c68a8f3c00',1,'QXmppArchiveListIq']]],
  ['setclient',['setClient',['../classQXmppClientExtension.html#a166f42a22447341abb26bd9c44c97590',1,'QXmppClientExtension']]],
  ['setclientcapabilitiesnode',['setClientCapabilitiesNode',['../classQXmppDiscoveryManager.html#a1c2405c6d1090a770af99336b87298a0',1,'QXmppDiscoveryManager']]],
  ['setclientcategory',['setClientCategory',['../classQXmppDiscoveryManager.html#a032ece84805598d51018724ac033e2ea',1,'QXmppDiscoveryManager']]],
  ['setclientname',['setClientName',['../classQXmppDiscoveryManager.html#abde090985f4963ef2f113a7a9b1330b3',1,'QXmppDiscoveryManager::setClientName()'],['../classQXmppVersionManager.html#a3ff80230bbf8b1eff98e4cc3bf96cccf',1,'QXmppVersionManager::setClientName()']]],
  ['setclientos',['setClientOs',['../classQXmppVersionManager.html#ade1da8db8747b949e03077c612dda6fe',1,'QXmppVersionManager']]],
  ['setclientpresence',['setClientPresence',['../classQXmppClient.html#ad47d8d9bd5e44dd2566ff0d726b1e71b',1,'QXmppClient']]],
  ['setclienttype',['setClientType',['../classQXmppDiscoveryManager.html#abdb3cf2844cec7c864fe855fa86af5b1',1,'QXmppDiscoveryManager']]],
  ['setclientvcard',['setClientVCard',['../classQXmppVCardManager.html#a72cce6a88629d3a04996a3b4d9d420f5',1,'QXmppVCardManager']]],
  ['setclientversion',['setClientVersion',['../classQXmppVersionManager.html#a1fc93184ad42a74d205dc3d93cc084ae',1,'QXmppVersionManager']]],
  ['setclockrate',['setClockrate',['../classQXmppJinglePayloadType.html#a25d8fa0e0a23e70e72b544f7cd073da6',1,'QXmppJinglePayloadType']]],
  ['setcommand',['setCommand',['../classQXmppDialback.html#a8b3ac2f6733dc576ca2295d4017f1038',1,'QXmppDialback']]],
  ['setcomponent',['setComponent',['../classQXmppJingleCandidate.html#a7b22b0429af93096540abca2f5e2eb60',1,'QXmppJingleCandidate::setComponent()'],['../classQXmppIceComponent.html#a5fb86a2ff46687f40dc8db07ef4e6951',1,'QXmppIceComponent::setComponent()']]],
  ['setconferences',['setConferences',['../classQXmppBookmarkSet.html#a8486913b3825114b7ce31f313871fa81',1,'QXmppBookmarkSet']]],
  ['setconfiguration',['setConfiguration',['../classQXmppMucRoom.html#a15377792c8bec23191b34a6759c330ab',1,'QXmppMucRoom']]],
  ['setcontents',['setContents',['../classQXmppPubSubItem.html#a649ac84705dd748c05d4a436010c6f36',1,'QXmppPubSubItem']]],
  ['setdate',['setDate',['../classQXmppArchiveMessage.html#aa459ddea8ffa849b8e408625e6f456a8',1,'QXmppArchiveMessage']]],
  ['setdescription',['setDescription',['../classQXmppDataForm_1_1Field.html#acc1ea1b44c059ab10e87f0ae147fca18',1,'QXmppDataForm::Field']]],
  ['setdigest',['setDigest',['../classQXmppPasswordReply.html#a523c595ac1c6f1a006cec1bb184b6050',1,'QXmppPasswordReply']]],
  ['setdomain',['setDomain',['../classQXmppConfiguration.html#a716050cec0aa3fc11e6f4fbfb1e6d4a1',1,'QXmppConfiguration::setDomain()'],['../classQXmppPasswordRequest.html#a576c39a66597ea614abbb1639b2f6c73',1,'QXmppPasswordRequest::setDomain()'],['../classQXmppServer.html#aa0eeb8f1680923e70492596cb4f7e02a',1,'QXmppServer::setDomain()']]],
  ['setemail',['setEmail',['../classQXmppVCardIq.html#abc7c73030e09607ce9cae339ceef73d0',1,'QXmppVCardIq']]],
  ['setend',['setEnd',['../classQXmppArchiveListIq.html#af3392d03c60aef8eb5563c503d3a0a83',1,'QXmppArchiveListIq::setEnd()'],['../classQXmppArchiveRemoveIq.html#a7d5ebc04183d98ffbe96a6b6009d8960',1,'QXmppArchiveRemoveIq::setEnd()']]],
  ['seterror',['setError',['../classQXmppStanza.html#a59cd978cb7dd23671cb679be53c4bd4b',1,'QXmppStanza::setError()'],['../classQXmppPasswordReply.html#aa44e00eacb445af75c46129d63c6234b',1,'QXmppPasswordReply::setError()']]],
  ['setextensions',['setExtensions',['../classQXmppStanza.html#accbc3c11a988b9e3a69fa099fcf9f5fb',1,'QXmppStanza']]],
  ['setfacebookaccesstoken',['setFacebookAccessToken',['../classQXmppConfiguration.html#af1c8f373cd71d6b3287a6d970dfb7ad4',1,'QXmppConfiguration']]],
  ['setfacebookappid',['setFacebookAppId',['../classQXmppConfiguration.html#a881fe44df96b52653c81823c55fb46cd',1,'QXmppConfiguration']]],
  ['setfaultcode',['setFaultCode',['../classQXmppRpcResponseIq.html#a64352b119ec3da44c44542d6c58548c1',1,'QXmppRpcResponseIq']]],
  ['setfaultstring',['setFaultString',['../classQXmppRpcResponseIq.html#a6c14545d9bcbb4f610a5c0f049bd9e5c',1,'QXmppRpcResponseIq']]],
  ['setfields',['setFields',['../classQXmppDataForm.html#ac907784586541e0a79dd8d966e955f0f',1,'QXmppDataForm']]],
  ['setfirstname',['setFirstName',['../classQXmppVCardIq.html#a98b1ee2bf954f929777928791f7a53fe',1,'QXmppVCardIq']]],
  ['setform',['setForm',['../classQXmppMucOwnerIq.html#a02712467d300d6aad4213ddd7bff1bf2',1,'QXmppMucOwnerIq']]],
  ['setformat',['setFormat',['../classQXmppVideoEncoder.html#af93109d87d4c00f24370dd6c5963fdb0',1,'QXmppVideoEncoder']]],
  ['setfoundation',['setFoundation',['../classQXmppJingleCandidate.html#aba966a89d765a54fbe15a453074c5bcd',1,'QXmppJingleCandidate']]],
  ['setfrom',['setFrom',['../classQXmppStanza.html#a320ae1faad87e443277a36260cefb85a',1,'QXmppStanza']]],
  ['setfullname',['setFullName',['../classQXmppVCardIq.html#a3f72cb68b4c2dc1120a3803d75b01b62',1,'QXmppVCardIq']]],
  ['setgroups',['setGroups',['../classQXmppRosterIq_1_1Item.html#ade2430a52808649b51ed9c6b554cf77a',1,'QXmppRosterIq::Item']]],
  ['sethost',['setHost',['../classQXmppJingleCandidate.html#a89f496aa65b0610af6c86c44120582aa',1,'QXmppJingleCandidate::setHost()'],['../classQXmppConfiguration.html#a97320e5239f46770edcd457301b41809',1,'QXmppConfiguration::setHost()']]],
  ['seticecontrolling',['setIceControlling',['../classQXmppIceComponent.html#a679e8e78807464df76feed30495b7fe7',1,'QXmppIceComponent::setIceControlling()'],['../classQXmppIceConnection.html#a27972dd93469a303586e22cd4709b84e',1,'QXmppIceConnection::setIceControlling()']]],
  ['setid',['setId',['../classQXmppJinglePayloadType.html#a54a81639dc575b99cf4a42a24b7de65b',1,'QXmppJinglePayloadType::setId()'],['../classQXmppJingleCandidate.html#a1b92b6622dde36f6d8ad3f63138aba63',1,'QXmppJingleCandidate::setId()'],['../classQXmppPubSubItem.html#a0e3419b22bd11e146d99447c948e7014',1,'QXmppPubSubItem::setId()'],['../classQXmppStanza.html#aee06ffcdc8c7b7d67b2da536640e188d',1,'QXmppStanza::setId()']]],
  ['setignoresslerrors',['setIgnoreSslErrors',['../classQXmppConfiguration.html#af6075135d8735c7c6b95d7538a2c7245',1,'QXmppConfiguration']]],
  ['setinactivitytimeout',['setInactivityTimeout',['../classQXmppIncomingClient.html#ac2dc764e675d481d5afbe6e612765633',1,'QXmppIncomingClient']]],
  ['setinitiator',['setInitiator',['../classQXmppJingleIq.html#ae2ff3ea68609d6bcd79c41e0e6351730',1,'QXmppJingleIq']]],
  ['setinstructions',['setInstructions',['../classQXmppDataForm.html#a86b49fc4668777e80c523c8bbea29af0',1,'QXmppDataForm']]],
  ['setitems',['setItems',['../classQXmppMucAdminIq.html#a842d537a6cf06b01d26b200eae70c43d',1,'QXmppMucAdminIq::setItems()'],['../classQXmppPubSubIq.html#af8e713430dbba5da0ca5448fada723ce',1,'QXmppPubSubIq::setItems()']]],
  ['setjid',['setJid',['../classQXmppBindIq.html#acac65e047ba7c879b43dcd912dfc276b',1,'QXmppBindIq::setJid()'],['../classQXmppBookmarkConference.html#a2ced3c41b583ff5136a9d818c0d586b5',1,'QXmppBookmarkConference::setJid()'],['../classQXmppMucItem.html#a0c2cc3987d51a7d5fad68569c686af59',1,'QXmppMucItem::setJid()'],['../classQXmppConfiguration.html#a26c876dbe4b4adb39497ecbab5793bd6',1,'QXmppConfiguration::setJid()']]],
  ['setkeepaliveinterval',['setKeepAliveInterval',['../classQXmppConfiguration.html#a6d47839bca9fbcebb1fe3ce2f5fce6fd',1,'QXmppConfiguration']]],
  ['setkeepalivetimeout',['setKeepAliveTimeout',['../classQXmppConfiguration.html#acd5867aea24580d8aa0647750a420020',1,'QXmppConfiguration']]],
  ['setkey',['setKey',['../classQXmppDataForm_1_1Field.html#a4ab9994979e765bbd65d4463d7910b6e',1,'QXmppDataForm::Field::setKey()'],['../classQXmppDialback.html#a91a464ea608a5924340593a075b9352a',1,'QXmppDialback::setKey()']]],
  ['setlabel',['setLabel',['../classQXmppDataForm_1_1Field.html#aee48675b341d4a4b990f146434ff2eeb',1,'QXmppDataForm::Field']]],
  ['setlang',['setLang',['../classQXmppStanza.html#a16c60bf49fe9bdf3c74f4d99b05ddee2',1,'QXmppStanza']]],
  ['setlastname',['setLastName',['../classQXmppVCardIq.html#ae3e28bae362398ad657dfc53a4b04c47',1,'QXmppVCardIq']]],
  ['setlocalcertificate',['setLocalCertificate',['../classQXmppServer.html#ac8e8e8e321d36d965fbb38fbd7a8fc54',1,'QXmppServer::setLocalCertificate()'],['../classQXmppSslServer.html#a4fba408dbc5cdd0b093867b8da757ac3',1,'QXmppSslServer::setLocalCertificate()']]],
  ['setlocalfileurl',['setLocalFileUrl',['../classQXmppTransferJob.html#a7f5bf8cfe96d0e8464ac63ff0f2089ae',1,'QXmppTransferJob']]],
  ['setlocalpassword',['setLocalPassword',['../classQXmppIceComponent.html#a93374c2cbe66380376f3e56cb5574243',1,'QXmppIceComponent::setLocalPassword()'],['../classQXmppIceConnection.html#a00eb97dd173d5952796f085dc6ba85f2',1,'QXmppIceConnection::setLocalPassword()']]],
  ['setlocalstreamkey',['setLocalStreamKey',['../classQXmppOutgoingServer.html#a04c2358e7fb7e1ce716b37ae52364586',1,'QXmppOutgoingServer']]],
  ['setlocaluser',['setLocalUser',['../classQXmppIceComponent.html#a54e3b9c597142d10f4f05b817a3aec6c',1,'QXmppIceComponent::setLocalUser()'],['../classQXmppIceConnection.html#aa245f34197f786c010fe4c27a7d73a77',1,'QXmppIceConnection::setLocalUser()']]],
  ['setlogfilepath',['setLogFilePath',['../classQXmppLogger.html#a3a67ae630d032b8bdac039fe0567e178',1,'QXmppLogger']]],
  ['setlogger',['setLogger',['../classQXmppClient.html#aa799549089f2ecbe9796f53d0f7be6d2',1,'QXmppClient::setLogger()'],['../classQXmppServer.html#a8d9cb8a46f45d52f9332933d6c38862c',1,'QXmppServer::setLogger()']]],
  ['setloggingtype',['setLoggingType',['../classQXmppLogger.html#a0b60be94fa2f768d3eabcdba8357f15b',1,'QXmppLogger']]],
  ['setmax',['setMax',['../classQXmppArchiveListIq.html#af6a45d1b3274fa3488aea4adad92c934',1,'QXmppArchiveListIq::setMax()'],['../classQXmppArchiveRetrieveIq.html#a79fc0c683558cf31029ca9e1c71b9856',1,'QXmppArchiveRetrieveIq::setMax()']]],
  ['setmaxptime',['setMaxptime',['../classQXmppJinglePayloadType.html#a78d6fd7ba582123bc1fdd35530bcbc46',1,'QXmppJinglePayloadType']]],
  ['setmessages',['setMessages',['../classQXmppArchiveChat.html#aff362d598bec87709af80fc98e0cde28',1,'QXmppArchiveChat']]],
  ['setmessagetypes',['setMessageTypes',['../classQXmppLogger.html#a8be64f1219d725ba66a60c8970e53bb7',1,'QXmppLogger']]],
  ['setmethod',['setMethod',['../classQXmppRpcInvokeIq.html#a53cbf15b11ed4fb42f6179d005d03f63',1,'QXmppRpcInvokeIq']]],
  ['setmiddlename',['setMiddleName',['../classQXmppVCardIq.html#aba227d72ed8301ffbe1c7e9a64e068db',1,'QXmppVCardIq']]],
  ['setmucitem',['setMucItem',['../classQXmppPresence.html#a39b28a9d2a741f20ead461407cba5696',1,'QXmppPresence']]],
  ['setmucstatuscodes',['setMucStatusCodes',['../classQXmppPresence.html#a1a3b34af72d4073c4de1ab83695287d0',1,'QXmppPresence']]],
  ['setname',['setName',['../classQXmppBookmarkConference.html#a9e68254ad4f145e735ab3e65e9e7c4e5',1,'QXmppBookmarkConference::setName()'],['../classQXmppBookmarkUrl.html#ae151acb6db6d984b5f145963f6b2ba67',1,'QXmppBookmarkUrl::setName()'],['../classQXmppJinglePayloadType.html#accafc5198b67b5f5069f54f2a941fc1f',1,'QXmppJinglePayloadType::setName()'],['../classQXmppRosterIq_1_1Item.html#a3ec918e6d85d1b318dc769799cdd9d2d',1,'QXmppRosterIq::Item::setName()'],['../classQXmppVersionIq.html#af65b2a5e43a0af8449ed36018147b474',1,'QXmppVersionIq::setName()']]],
  ['setnetwork',['setNetwork',['../classQXmppJingleCandidate.html#ad31d46f6c78c57a2db0825def8a3c640',1,'QXmppJingleCandidate']]],
  ['setnetworkproxy',['setNetworkProxy',['../classQXmppConfiguration.html#a57e5382b3283912576e2953742529cb5',1,'QXmppConfiguration']]],
  ['setnick',['setNick',['../classQXmppMucItem.html#ab454e1b4e6edb28f07c95ffb56df33a2',1,'QXmppMucItem']]],
  ['setnickname',['setNickName',['../classQXmppBookmarkConference.html#a8e8277024e367af04c433ebe02053346',1,'QXmppBookmarkConference::setNickName()'],['../classQXmppVCardIq.html#aa450262ecf9fd3d196464484add3069f',1,'QXmppVCardIq::setNickName()'],['../classQXmppMucRoom.html#a484129fde79e5ee841757d94d7eed5cc',1,'QXmppMucRoom::setNickName()']]],
  ['setnonsaslauthmechanism',['setNonSASLAuthMechanism',['../classQXmppConfiguration.html#a9dfd3f8b383c5996ff4906e5d3d62807',1,'QXmppConfiguration']]],
  ['setoptions',['setOptions',['../classQXmppDataForm_1_1Field.html#a08ff329fad506d69af660bfb9e4174fb',1,'QXmppDataForm::Field']]],
  ['setos',['setOs',['../classQXmppVersionIq.html#a8f6e8a6b8b02b98f99c12dfa8df78023',1,'QXmppVersionIq']]],
  ['setparameters',['setParameters',['../classQXmppVideoDecoder.html#a97338b2f599569651e9176d8a37542da',1,'QXmppVideoDecoder::setParameters()'],['../classQXmppJinglePayloadType.html#a3c17aed60c502b37ada75ed8e7e256e0',1,'QXmppJinglePayloadType::setParameters()']]],
  ['setpassword',['setPassword',['../classQXmppConfiguration.html#ab1deabbad52755bda2d975d5150dbf7a',1,'QXmppConfiguration::setPassword()'],['../classQXmppMucRoom.html#adfb1f258f106805c76bc501e8ea162f6',1,'QXmppMucRoom::setPassword()'],['../classQXmppPasswordRequest.html#a81b68dceb87c75e0dbfe79cdb05dc426',1,'QXmppPasswordRequest::setPassword()'],['../classQXmppPasswordReply.html#a11f9eccc067fc48dd09237499cccb53f',1,'QXmppPasswordReply::setPassword()']]],
  ['setpasswordchecker',['setPasswordChecker',['../classQXmppIncomingClient.html#a6c2286e741e49b582db08b8ddbffe5cb',1,'QXmppIncomingClient::setPasswordChecker()'],['../classQXmppServer.html#ae797b5932a1fe33d234677deea4bf5ac',1,'QXmppServer::setPasswordChecker()']]],
  ['setpermissions',['setPermissions',['../classQXmppMucRoom.html#a7bef5394e4cd2af9c57f13fb4c8dadf7',1,'QXmppMucRoom']]],
  ['setphoto',['setPhoto',['../classQXmppVCardIq.html#a02fbd4d1b746daf9528ed60a14c586ac',1,'QXmppVCardIq']]],
  ['setphotohash',['setPhotoHash',['../classQXmppPresence.html#ac1df0dc4749bac5370267a05101c84ca',1,'QXmppPresence']]],
  ['setphototype',['setPhotoType',['../classQXmppVCardIq.html#ad80c63e75fd3cdd293b3732e3e8f5591',1,'QXmppVCardIq']]],
  ['setport',['setPort',['../classQXmppJingleCandidate.html#a3dd0a3979c5547beaa5959c24e06bbd0',1,'QXmppJingleCandidate::setPort()'],['../classQXmppConfiguration.html#af6d5a5df2a2100302fef321298bb0d0b',1,'QXmppConfiguration::setPort()']]],
  ['setpriority',['setPriority',['../classQXmppJingleCandidate.html#ac6ec59469d6d7c33b90a67873ff19faa',1,'QXmppJingleCandidate::setPriority()'],['../classQXmppPresence_1_1Status.html#a69ec69bc8e4ef6c3ee2c299f29d20ca6',1,'QXmppPresence::Status::setPriority()']]],
  ['setprivatekey',['setPrivateKey',['../classQXmppServer.html#a37741e9135fbd5b2ed26d5d9d24b2f79',1,'QXmppServer::setPrivateKey()'],['../classQXmppSslServer.html#ab1dfa5bc69ca5f2ea98ad87f586d69cd',1,'QXmppSslServer::setPrivateKey()']]],
  ['setprotocol',['setProtocol',['../classQXmppJingleCandidate.html#a554314b9bf1f86b58abb1cea409c0a89',1,'QXmppJingleCandidate']]],
  ['setproxy',['setProxy',['../classQXmppTransferManager.html#ad7d0f0496c85b85b448010d8a3c86d23',1,'QXmppTransferManager']]],
  ['setproxyonly',['setProxyOnly',['../classQXmppTransferManager.html#a46b2fc83d7773ae755e04a775694b5b8',1,'QXmppTransferManager']]],
  ['setptime',['setPtime',['../classQXmppJinglePayloadType.html#a55217b43a1ed57ef2fd03f9e9d000870',1,'QXmppJinglePayloadType']]],
  ['setqueryjid',['setQueryJid',['../classQXmppPubSubIq.html#a3baec6f49cf3be7cbe0aa674fd263a27',1,'QXmppPubSubIq']]],
  ['setquerynode',['setQueryNode',['../classQXmppPubSubIq.html#a4536330850f2ae8ef384062ee39f158c',1,'QXmppPubSubIq']]],
  ['setquerytype',['setQueryType',['../classQXmppPubSubIq.html#a67fecb1af8f3cc615abed963d9503752',1,'QXmppPubSubIq']]],
  ['setreason',['setReason',['../classQXmppMucItem.html#ac4e4bf962ca2b6f5b14126938930434e',1,'QXmppMucItem']]],
  ['setreceiptid',['setReceiptId',['../classQXmppMessage.html#a104137c6a141edae8da9678fb07429eb',1,'QXmppMessage']]],
  ['setreceiptrequested',['setReceiptRequested',['../classQXmppMessage.html#a7ea77ae7738907a21a41d4dc3da767a6',1,'QXmppMessage']]],
  ['setreceived',['setReceived',['../classQXmppArchiveMessage.html#ad50506d533febb834db77813fb234389',1,'QXmppArchiveMessage']]],
  ['setremotepassword',['setRemotePassword',['../classQXmppIceComponent.html#a13d7b92269d4af812a19d042d6c1aceb',1,'QXmppIceComponent::setRemotePassword()'],['../classQXmppIceConnection.html#aafcb1ab8fd41cda479adba2f5da000f8',1,'QXmppIceConnection::setRemotePassword()']]],
  ['setremoteuser',['setRemoteUser',['../classQXmppIceComponent.html#a675c8f43d6d57cbe45e57efb557cd443',1,'QXmppIceComponent::setRemoteUser()'],['../classQXmppIceConnection.html#a57eadc3aad0a3f83eb697fa58612cd83',1,'QXmppIceConnection::setRemoteUser()']]],
  ['setrequired',['setRequired',['../classQXmppDataForm_1_1Field.html#aa1067cc412a7b39de116283e5bfcab2b',1,'QXmppDataForm::Field']]],
  ['setresource',['setResource',['../classQXmppBindIq.html#a1b34fadd2b220216e5ab508ca8e9dbe7',1,'QXmppBindIq::setResource()'],['../classQXmppConfiguration.html#a1194a37607906daa26bbefae8e28a43f',1,'QXmppConfiguration::setResource()']]],
  ['setresponder',['setResponder',['../classQXmppJingleIq.html#a31efd22d113f8adb25d0426781506429',1,'QXmppJingleIq']]],
  ['setringing',['setRinging',['../classQXmppJingleIq.html#a1b7383c7480885a0830b48d115968e27',1,'QXmppJingleIq']]],
  ['setrole',['setRole',['../classQXmppMucItem.html#aa54c2637d43ad27edfd427db5b8b901d',1,'QXmppMucItem']]],
  ['setsaslauthmechanism',['setSASLAuthMechanism',['../classQXmppConfiguration.html#a964dd39de84d326d8e60278db789ee85',1,'QXmppConfiguration']]],
  ['setsid',['setSid',['../classQXmppJingleIq.html#a129f1b4d2bc61b88ac8f96bf2085cf3f',1,'QXmppJingleIq']]],
  ['setsocket',['setSocket',['../classQXmppStream.html#a108216277f9a42ef3b252a46caeb5288',1,'QXmppStream']]],
  ['setsockets',['setSockets',['../classQXmppIceComponent.html#a315d2979cabe2ef7452d5f20da45dd31',1,'QXmppIceComponent']]],
  ['setstamp',['setStamp',['../classQXmppMessage.html#a9f2a9f5b56fa023f649c372f95fbf1af',1,'QXmppMessage']]],
  ['setstart',['setStart',['../classQXmppArchiveChat.html#a807add48c951860e7fa791e9b5729b5a',1,'QXmppArchiveChat::setStart()'],['../classQXmppArchiveListIq.html#a8cd1c9ab52c5043bfd046fcd02f5af61',1,'QXmppArchiveListIq::setStart()'],['../classQXmppArchiveRemoveIq.html#ab5b5c3d1a7a4f9b0b26aad50f1112d0c',1,'QXmppArchiveRemoveIq::setStart()'],['../classQXmppArchiveRetrieveIq.html#a9d1ad99cfbff05e309a194bb050290b9',1,'QXmppArchiveRetrieveIq::setStart()']]],
  ['setstate',['setState',['../classQXmppMessage.html#a3859bd7236f3bc19f908cec612c295d2',1,'QXmppMessage']]],
  ['setstatistics',['setStatistics',['../classQXmppServerExtension.html#ae630cd2f9a26df0ec939538e2c734ca0',1,'QXmppServerExtension']]],
  ['setstatus',['setStatus',['../classQXmppPresence.html#ada057ee0be3be0b8b7e9d7067337ba66',1,'QXmppPresence']]],
  ['setstatustext',['setStatusText',['../classQXmppPresence_1_1Status.html#a38b5511e9fc189ff0d064ac0de191d27',1,'QXmppPresence::Status']]],
  ['setstreamsecuritymode',['setStreamSecurityMode',['../classQXmppConfiguration.html#a299a81b1f6187b3be2d8bdc063b1f732',1,'QXmppConfiguration']]],
  ['setstunserver',['setStunServer',['../classQXmppIceComponent.html#a93d01d02d0458597f90e3d3aaea51948',1,'QXmppIceComponent::setStunServer()'],['../classQXmppIceConnection.html#a172ef45ea78d084f495163b1816f0cec',1,'QXmppIceConnection::setStunServer()'],['../classQXmppCallManager.html#aab04548bb154fca0f6a0d619a337c989',1,'QXmppCallManager::setStunServer()']]],
  ['setsubject',['setSubject',['../classQXmppArchiveChat.html#af672abee71578730bd3f62afd5c8e3e2',1,'QXmppArchiveChat::setSubject()'],['../classQXmppMessage.html#a4b2b4eb5c07495d28c70ebf660bf32fd',1,'QXmppMessage::setSubject()'],['../classQXmppMucRoom.html#adf884eda82895acbdd26ab5918257429',1,'QXmppMucRoom::setSubject()']]],
  ['setsubscriptionid',['setSubscriptionId',['../classQXmppPubSubIq.html#a0b095ae35bd4f84dafa9f0730d3d1e62',1,'QXmppPubSubIq']]],
  ['setsubscriptionstatus',['setSubscriptionStatus',['../classQXmppRosterIq_1_1Item.html#af43b7efd16697d56e2e88ffdc5ff2929',1,'QXmppRosterIq::Item']]],
  ['setsubscriptiontype',['setSubscriptionType',['../classQXmppRosterIq_1_1Item.html#aa9f572853402d0094676e524439b6383',1,'QXmppRosterIq::Item']]],
  ['setsupportedmethods',['setSupportedMethods',['../classQXmppTransferManager.html#a1a6894de4393135f7f80488f180a6ea2',1,'QXmppTransferManager']]],
  ['setthread',['setThread',['../classQXmppArchiveChat.html#a75ab3d8e36075ff65d5d81618aa1f7bf',1,'QXmppArchiveChat::setThread()'],['../classQXmppMessage.html#a36ed8d1190f50b78af05ce806c1e90a6',1,'QXmppMessage::setThread()']]],
  ['settitle',['setTitle',['../classQXmppDataForm.html#afa08e0e1f30260375d1d846bcf20bc20',1,'QXmppDataForm']]],
  ['setto',['setTo',['../classQXmppStanza.html#a8296bac9c1821141bb67fae87910b8e0',1,'QXmppStanza']]],
  ['setturnpassword',['setTurnPassword',['../classQXmppIceComponent.html#a9dcbf749ad6050caa8c905cc581f5a5b',1,'QXmppIceComponent::setTurnPassword()'],['../classQXmppIceConnection.html#a1cb5ba7634ffcba433bc8b920ab2f859',1,'QXmppIceConnection::setTurnPassword()'],['../classQXmppCallManager.html#afcdf20af9e802cdabdb864daad5da7d7',1,'QXmppCallManager::setTurnPassword()']]],
  ['setturnserver',['setTurnServer',['../classQXmppIceComponent.html#aad43d7618d8abd66d549d37cca62c92f',1,'QXmppIceComponent::setTurnServer()'],['../classQXmppIceConnection.html#afd6f1bb0abdacba3a31bc66ed0a947db',1,'QXmppIceConnection::setTurnServer()'],['../classQXmppCallManager.html#a64feb39c4d6605d08896eeebdbbc2ae5',1,'QXmppCallManager::setTurnServer()']]],
  ['setturnuser',['setTurnUser',['../classQXmppIceComponent.html#a6b178961cf8e7b08c8c2f41f41be9f8f',1,'QXmppIceComponent::setTurnUser()'],['../classQXmppIceConnection.html#a4a64db6163995de3d213706306a3e663',1,'QXmppIceConnection::setTurnUser()'],['../classQXmppCallManager.html#ad516ee9d7304b7ef8dbf0e28c8baaa55',1,'QXmppCallManager::setTurnUser()']]],
  ['settype',['setType',['../classQXmppDataForm_1_1Field.html#ad35131a068782d9ab9871b07fee6f774',1,'QXmppDataForm::Field::setType()'],['../classQXmppDataForm.html#a78ba23e3b14a3367be036c94b7a52a0a',1,'QXmppDataForm::setType()'],['../classQXmppIq.html#ab4b5d1e875aeace442ac8828946ba2fe',1,'QXmppIq::setType()'],['../classQXmppJingleCandidate.html#a6fbb56ccff5afcef3a78fc7c2875c29d',1,'QXmppJingleCandidate::setType()'],['../classQXmppMessage.html#a794cd10f4265b4b7d9ef5e9fb6e0c9f0',1,'QXmppMessage::setType()'],['../classQXmppPresence_1_1Status.html#a5fd46a28c3d5e6047ec93ef70075446b',1,'QXmppPresence::Status::setType()'],['../classQXmppPresence.html#a011e173528a981f49c7940f77e66db36',1,'QXmppPresence::setType()'],['../classQXmppDialback.html#a19eef491fa3d28ec65fa000aeb8e216a',1,'QXmppDialback::setType()']]],
  ['seturl',['setUrl',['../classQXmppBookmarkUrl.html#a7b61c601cb00b9038a3a894fb09ea305',1,'QXmppBookmarkUrl::setUrl()'],['../classQXmppVCardIq.html#a5036f61a15796c6cc6ba172c210b7c09',1,'QXmppVCardIq::setUrl()']]],
  ['seturls',['setUrls',['../classQXmppBookmarkSet.html#a64084ffccdb5ab1592aabadb318352e8',1,'QXmppBookmarkSet']]],
  ['setuser',['setUser',['../classQXmppConfiguration.html#a8cd27e7f2f584b6faa59a0f5cb1ee6b4',1,'QXmppConfiguration']]],
  ['setusername',['setUsername',['../classQXmppPasswordRequest.html#a0a84977feca05b3c5bc4df8e93dd5f96',1,'QXmppPasswordRequest']]],
  ['setusesaslauthentication',['setUseSASLAuthentication',['../classQXmppConfiguration.html#a4c9542ac86f8305e6cea4f2ad0366fb5',1,'QXmppConfiguration']]],
  ['setvalue',['setValue',['../classQXmppDataForm_1_1Field.html#a7326a294d7f809d8001b47fcd6be4dba',1,'QXmppDataForm::Field']]],
  ['setvalues',['setValues',['../classQXmppRpcResponseIq.html#a88e0e05de1bdc3bdd05e4ea8a8c61446',1,'QXmppRpcResponseIq']]],
  ['setvcardupdatetype',['setVCardUpdateType',['../classQXmppPresence.html#a094e60c4acb919bb618e78d7be512755',1,'QXmppPresence']]],
  ['setverify',['setVerify',['../classQXmppOutgoingServer.html#ab46469ded7de73e98e205625dcfe05a5',1,'QXmppOutgoingServer']]],
  ['setversion',['setVersion',['../classQXmppArchiveChat.html#a05cab859aa158cb5948eee532991ec3e',1,'QXmppArchiveChat::setVersion()'],['../classQXmppVersionIq.html#a70da818941802b0270b92db779a46fe6',1,'QXmppVersionIq::setVersion()']]],
  ['setwith',['setWith',['../classQXmppArchiveChat.html#ac2e70182971fcc63b9f40f603f07adc3',1,'QXmppArchiveChat::setWith()'],['../classQXmppArchiveListIq.html#af87f5d02c0c953d469399fde7075ec49',1,'QXmppArchiveListIq::setWith()'],['../classQXmppArchiveRemoveIq.html#a9f7bb87b8346fa0b83bce5149c50d496',1,'QXmppArchiveRemoveIq::setWith()'],['../classQXmppArchiveRetrieveIq.html#a067eb2f626d88847ff185b1e770a095e',1,'QXmppArchiveRetrieveIq::setWith()']]],
  ['sid',['sid',['../classQXmppJingleIq.html#a846549a7ce2ff322b466902a454ba4e5',1,'QXmppJingleIq::sid()'],['../classQXmppCall.html#a1a47d872cb001717eb7644dd6f168926',1,'QXmppCall::sid()'],['../classQXmppTransferJob.html#a02a1bfd07e06be44c23a2d1c559faba7',1,'QXmppTransferJob::sid()']]],
  ['signallogging',['SignalLogging',['../classQXmppLogger.html#a9a52fe426322ef8e10e05b7092be6c20ab2099e2e223040f603936071cc71b462',1,'QXmppLogger']]],
  ['size',['size',['../classQXmppVideoFrame.html#a1ea7f893dc931c3c32d9169a1f07be92',1,'QXmppVideoFrame']]],
  ['socket',['socket',['../classQXmppStream.html#acf771736ced3f18a0a763eb3b161b9c9',1,'QXmppStream::socket()'],['../classQXmppOutgoingClient.html#aca9b91ad84dc40275e4aa317f12ffa5c',1,'QXmppOutgoingClient::socket()']]],
  ['socketerror',['socketError',['../classQXmppClient.html#a2b044b37ce88a2f2e65833b3d6e57a9f',1,'QXmppClient::socketError()'],['../classQXmppClient.html#a7c2851d07cc33119752abc6ec8ffc47aac48e9688ca9dce21676283ada1172863',1,'QXmppClient::SocketError()']]],
  ['socksmethod',['SocksMethod',['../classQXmppTransferJob.html#a962582d3049909305277e54e2095c71ba81571d8573b2003f6f3a66fcda644815',1,'QXmppTransferJob']]],
  ['speed',['speed',['../classQXmppTransferJob.html#ad4a631dda697f59eb03bf373aeddf6a6',1,'QXmppTransferJob']]],
  ['stamp',['stamp',['../classQXmppMessage.html#a75532528f320e94dc030f4a6e7ea9fbc',1,'QXmppMessage']]],
  ['stanzas',['Stanzas',['../group__Stanzas.html',1,'']]],
  ['start',['start',['../classQXmppArchiveChat.html#a92f75a9737deb2ce322c2767634ab935',1,'QXmppArchiveChat::start()'],['../classQXmppArchiveListIq.html#abc3a47af035fd370e193e4fedac525f3',1,'QXmppArchiveListIq::start()'],['../classQXmppArchiveRemoveIq.html#afee3c666048c4cb211753e3dc0a54822',1,'QXmppArchiveRemoveIq::start()'],['../classQXmppArchiveRetrieveIq.html#ac8d0606440dd22b189e48521b50e46d1',1,'QXmppArchiveRetrieveIq::start()'],['../classQXmppServerExtension.html#a5341d9bb242ac64b996a35219eac1679',1,'QXmppServerExtension::start()']]],
  ['startstate',['StartState',['../classQXmppTransferJob.html#aab5bb06ca0d2c4f1fac33b7012d1c14faab96ac5cd1310e66c6048512f0846d66',1,'QXmppTransferJob']]],
  ['starttone',['startTone',['../classQXmppRtpAudioChannel.html#a70b63c9ec09cc6d2a39403e4b680581a',1,'QXmppRtpAudioChannel']]],
  ['startvideo',['startVideo',['../classQXmppCall.html#a08cfa042104fbdd80019c38670cd02b2',1,'QXmppCall']]],
  ['state',['state',['../classQXmppCall.html#aa09971e040121ffef56577a537be35a1',1,'QXmppCall::state()'],['../classQXmppClient.html#ac4cbb2e04e5ca683fadbc79ef173f0a5',1,'QXmppClient::state()'],['../classQXmppTransferJob.html#a51e1adb470053f12c5d5b2a10887c8f3',1,'QXmppTransferJob::state()'],['../classQXmppMessage.html#af90654a174ae92bb7904ed01b4d81dc4',1,'QXmppMessage::state() const '],['../classQXmppMessage.html#aeaa3cc5ccb7d451067a80dd1f3c7099a',1,'QXmppMessage::State()'],['../classQXmppCall.html#a90205b5034613127d2c4adc6a0252759',1,'QXmppCall::State()'],['../classQXmppClient.html#a5f4e70d508c08967f72fd41c5343ad2e',1,'QXmppClient::State()'],['../classQXmppTransferJob.html#aab5bb06ca0d2c4f1fac33b7012d1c14f',1,'QXmppTransferJob::State()']]],
  ['statechanged',['stateChanged',['../classQXmppCall.html#a16dd6c41d04900e322ce522d010cd513',1,'QXmppCall::stateChanged()'],['../classQXmppClient.html#a8bd2617265568c9769a8ba608a4ff05d',1,'QXmppClient::stateChanged()'],['../classQXmppTransferJob.html#a040ea186f586a3a9ffbc6e52b3cd3917',1,'QXmppTransferJob::stateChanged()']]],
  ['statistics',['statistics',['../classQXmppServer.html#ab0453751b0aab88ff0cbd2cc26d9a42d',1,'QXmppServer::statistics()'],['../classQXmppServerExtension.html#a7ed5df89f8ff04b67e7bf094d9d84461',1,'QXmppServerExtension::statistics()']]],
  ['status',['status',['../classQXmppPresence.html#a4ff79a31cc601e78ff05b6e5427093f4',1,'QXmppPresence::status()'],['../classQXmppPresence.html#a05d24001697e6dbb52962a7e66e0b221',1,'QXmppPresence::status() const '],['../classQXmppPresence_1_1Status.html#a037810a12b5682622f868bef7cbdcfca',1,'QXmppPresence::Status::Status()']]],
  ['status',['Status',['../classQXmppPresence_1_1Status.html',1,'QXmppPresence']]],
  ['statustext',['statusText',['../classQXmppPresence_1_1Status.html#a19efb38866b3bb10a465b71a8d19d973',1,'QXmppPresence::Status']]],
  ['stdoutlogging',['StdoutLogging',['../classQXmppLogger.html#a9a52fe426322ef8e10e05b7092be6c20acd51c8c54ebb5284752f224c69709998',1,'QXmppLogger']]],
  ['stop',['stop',['../classQXmppServerExtension.html#acbf4204a0bf898e70bf3e2fdceae6b09',1,'QXmppServerExtension']]],
  ['stoptone',['stopTone',['../classQXmppRtpAudioChannel.html#af19f7b1a9686dafaef24ff4fc9a2c3e6',1,'QXmppRtpAudioChannel']]],
  ['stopvideo',['stopVideo',['../classQXmppCall.html#afb995517f1cc43296000ba9321aefb74',1,'QXmppCall']]],
  ['streamsecuritymode',['streamSecurityMode',['../classQXmppConfiguration.html#ad9154f1c774a12a74692b5c1d2576ad8',1,'QXmppConfiguration::streamSecurityMode() const '],['../classQXmppConfiguration.html#a7c6e193a68beb792038c066cfc574a18',1,'QXmppConfiguration::StreamSecurityMode()']]],
  ['subject',['subject',['../classQXmppMucRoom.html#a7f95cf9bbd6fa253ca68312bd97f93dd',1,'QXmppMucRoom::subject()'],['../classQXmppArchiveChat.html#a56fa1f42874def672a0d4dc2501ca251',1,'QXmppArchiveChat::subject()'],['../classQXmppMessage.html#a4f7723d2f97362965151e32f666d4739',1,'QXmppMessage::subject()']]],
  ['subjectaction',['SubjectAction',['../classQXmppMucRoom.html#acd3129293f69d7e7cdd91b65aae0606fa1b691dc1004e867aa844ba380bb383ad',1,'QXmppMucRoom']]],
  ['subjectchanged',['subjectChanged',['../classQXmppMucRoom.html#a3ebda02e7b225cf6bdc264290c40b5a7',1,'QXmppMucRoom']]],
  ['submit',['Submit',['../classQXmppDataForm.html#adab12c436b8c450e2b4f59da1aecadeeae6ab517a99b8c387056bd5d341de4082',1,'QXmppDataForm']]],
  ['subscribe',['subscribe',['../classQXmppRosterManager.html#a866dbaaf87840ae04f5f44532aa7ccc0',1,'QXmppRosterManager::subscribe()'],['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da27a106dd1fc50ecdba0ad9b95307ce62',1,'QXmppPresence::Subscribe()']]],
  ['subscribed',['Subscribed',['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da59304e64fb15ce69c9395f6d217dcb6b',1,'QXmppPresence']]],
  ['subscriptionid',['subscriptionId',['../classQXmppPubSubIq.html#adb11498556fe6f224a50caa10e7a2e18',1,'QXmppPubSubIq']]],
  ['subscriptionreceived',['subscriptionReceived',['../classQXmppRosterManager.html#a3407f699aded8ed2724cdbb121678c4a',1,'QXmppRosterManager']]],
  ['subscriptionstatus',['subscriptionStatus',['../classQXmppRosterIq_1_1Item.html#aa32adf5d96267c3d4892f98cd37cd2d1',1,'QXmppRosterIq::Item']]],
  ['subscriptiontype',['subscriptionType',['../classQXmppRosterIq_1_1Item.html#a110aa10b3746d32e0b2e1f03c22b89c4',1,'QXmppRosterIq::Item::subscriptionType() const '],['../classQXmppRosterIq_1_1Item.html#a0133cf9262cec7e299c4db7c247c5514',1,'QXmppRosterIq::Item::SubscriptionType()']]],
  ['supportedmethods',['supportedMethods',['../classQXmppTransferManager.html#aeb4b1f1bb5e966f977d832014f0de9d8',1,'QXmppTransferManager']]]
];
